#Replication Code for Brian Palmer-Rubin, "Evading the Patronage Trap: Organizational Capacity and Demand-Making in Mexico," Comparative Political Studies

#Analysis conducted in R version 3.5.1

#install the following packages
library(texreg)
library(ggplot2)
library(cowplot)
library(xtable)


#Set working directory in the following line:
setwd("/Users/palmerrubinb/Dropbox/Marquette/Research/Patronage Trap/CPS/CPS revision/Patronage Trap, Replication materials")
load("repdatCPS.RData")

names(rep.dat)


########## Figure 2: Cross-Sector Comparison of Participation and Demand-Making Indices

# Function for SD
std <- function(x) sd(x,na.rm=T)

pdf(file="DV.pdf",width=12,height=8)

par(mar=c(5,13,4,2)+.1)
plot(c(0,6), c(0,10), type = "n", xlab="",ylab="",xaxt="n",yaxt="n",bty="n")

axis(2,at=c(1.5,3.5,5.5,7.5,9.5),labels=c("Distributive\nDemands", "Programmatic\nDemands","Extra-Inst.\nParticipation","Electoral\nParticipation","Institutional\nParticipation"),tick=F,las=1,cex.axis=2)

axis(1, at=c(0,1,2,3,4,5,6,7,8,9,10),labels=c(0,1,2,3,4,5,6,7,8,9,10),las=1,lty=1,tick=T)

#abline(h=0,lty=2)
abline(h=2.5,lty=2)
abline(h=4.5,lty=2)
abline(h=6.5,lty=2)
abline(h=8.5,lty=2)


# Inst
points(mean(rep.dat$inst.index.6[rep.dat$Sector=="Agriculture"],na.rm=T),9.75,pch=19)

segments(mean(rep.dat$inst.index.6[rep.dat$Sector=="Agriculture"],na.rm=T)-std(rep.dat$inst.index.6[rep.dat$Sector=="Agriculture"]),9.75,mean(rep.dat$inst.index.6[rep.dat$Sector=="Agriculture"],na.rm=T)+std(rep.dat$inst.index.6[rep.dat$Sector=="Agriculture"]),9.75,lwd=2)

points(mean(rep.dat$inst.index.6[rep.dat$Sector=="Business"],na.rm=T),9.25,pch=19,col="gray47")

segments(mean(rep.dat$inst.index.6[rep.dat$Sector=="Business"],na.rm=T)-std(rep.dat$inst.index.6[rep.dat$Sector=="Business"]),9.25,mean(rep.dat$inst.index.6[rep.dat$Sector=="Business"],na.rm=T)+std(rep.dat$inst.index.6[rep.dat$Sector=="Business"]),9.25,lwd=2,col="gray47",lty=2)

# Electoral

points(mean(rep.dat$electoral.part.index[rep.dat$Sector=="Agriculture"],na.rm=T),7.75,pch=19)

segments(mean(rep.dat$electoral.part.index[rep.dat$Sector=="Agriculture"],na.rm=T)-std(rep.dat$electoral.part.index[rep.dat$Sector=="Agriculture"]),7.75,mean(rep.dat$electoral.part.index[rep.dat$Sector=="Agriculture"],na.rm=T)+std(rep.dat$electoral.part.index[rep.dat$Sector=="Agriculture"]),7.75,lwd=2)

points(mean(rep.dat$electoral.part.index[rep.dat$Sector=="Business"],na.rm=T),7.25,pch=19,col="gray47")

segments(mean(rep.dat$electoral.part.index[rep.dat$Sector=="Business"],na.rm=T)-std(rep.dat$electoral.part.index[rep.dat$Sector=="Business"]),7.25,mean(rep.dat$electoral.part.index[rep.dat$Sector=="Business"],na.rm=T)+std(rep.dat$electoral.part.index[rep.dat$Sector=="Business"]),7.25,lwd=2,col="gray47",lty=2)


# Extra-Inst

points(mean(rep.dat$extra.inst.index[rep.dat$Sector=="Agriculture"],na.rm=T),5.75,pch=19)

segments(mean(rep.dat$extra.inst.index[rep.dat$Sector=="Agriculture"],na.rm=T)-std(rep.dat$extra.inst.index[rep.dat$Sector=="Agriculture"]),5.75,mean(rep.dat$extra.inst.index[rep.dat$Sector=="Agriculture"],na.rm=T)+std(rep.dat$extra.inst.index[rep.dat$Sector=="Agriculture"]),5.75,lwd=2)

points(mean(rep.dat$extra.inst.index[rep.dat$Sector=="Business"],na.rm=T),5.25,pch=19,col="gray47")

segments(mean(rep.dat$extra.inst.index[rep.dat$Sector=="Business"],na.rm=T)-std(rep.dat$extra.inst.index[rep.dat$Sector=="Business"]),5.25,mean(rep.dat$extra.inst.index[rep.dat$Sector=="Business"],na.rm=T)+std(rep.dat$extra.inst.index[rep.dat$Sector=="Business"]),5.25,lwd=2,col="gray47",lty=2)


# Programmatic

points(mean(rep.dat$prog.index.6[rep.dat$Sector=="Agriculture"],na.rm=T),3.75,pch=19)

segments(mean(rep.dat$prog.index.6[rep.dat$Sector=="Agriculture"],na.rm=T)-std(rep.dat$prog.index.6[rep.dat$Sector=="Agriculture"]),3.75,mean(rep.dat$prog.index.6[rep.dat$Sector=="Agriculture"],na.rm=T)+std(rep.dat$prog.index.6[rep.dat$Sector=="Agriculture"]),3.75,lwd=2)

points(mean(rep.dat$prog.index.6[rep.dat$Sector=="Business"],na.rm=T),3.25,pch=19,col="gray47")

segments(mean(rep.dat$prog.index.6[rep.dat$Sector=="Business"],na.rm=T)-std(rep.dat$prog.index.6[rep.dat$Sector=="Business"]),3.25,mean(rep.dat$prog.index.6[rep.dat$Sector=="Business"],na.rm=T)+std(rep.dat$prog.index.6[rep.dat$Sector=="Business"]),3.25,lwd=2,col="gray47",lty=2)

# Subsidy
points(mean(rep.dat$subsidy.index.6[rep.dat$Sector=="Agriculture"],na.rm=T),1.75,pch=19)

segments(mean(rep.dat$subsidy.index.6[rep.dat$Sector=="Agriculture"],na.rm=T)-std(rep.dat$subsidy.index.6[rep.dat$Sector=="Agriculture"]),1.75,mean(rep.dat$subsidy.index.6[rep.dat$Sector=="Agriculture"],na.rm=T)+std(rep.dat$subsidy.index.6[rep.dat$Sector=="Agriculture"]),1.75,lwd=2)

points(mean(rep.dat$subsidy.index.6[rep.dat$Sector=="Business"],na.rm=T),1.25,pch=19,col="gray47")

segments(mean(rep.dat$subsidy.index.6[rep.dat$Sector=="Business"],na.rm=T)-std(rep.dat$subsidy.index.6[rep.dat$Sector=="Business"]),1.25,mean(rep.dat$subsidy.index.6[rep.dat$Sector=="Business"],na.rm=T)+std(rep.dat$subsidy.index.6[rep.dat$Sector=="Business"]),1.25,lwd=2,col="gray47",lty=2)

legend("bottomright",c("Agricultural Organizations","Business Organizations"),pch=19,lty=c(1,2),lwd=2,col=c("black","gray47"),cex=1.2)


dev.off()


##########################################################################################
### Table 3: Multivariate Models of Organizational Participation and Demand-Making

# Institutional Participation
inst1<-lm(inst.index.6~Recursos.num2+Servicios.num2+Porc.micro.no.prod2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y+Sector:Servicios.num2, data=rep.dat)

summary(inst1)

# Electoral Participation
elec1<-lm(electoral.part.index~Recursos.num2+Servicios.num2+Porc.micro.no.prod2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y+Sector:Servicios.num2, data=rep.dat)

summary(elec1)

# Extra-Institutional Participation
extra1<-lm(extra.inst.index~Recursos.num2+Servicios.num2+Porc.micro.no.prod2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y+Sector:Servicios.num2, data=rep.dat)

summary(extra1)

# Programmatic Demands
prog1<-lm(prog.index.6~Recursos.num2+Servicios.num2+Porc.micro.no.prod2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y+Sector:Servicios.num2, data=rep.dat)

summary(prog1)

# Distributive Demands
dist1<-lm(subsidy.index.6~Recursos.num2+Servicios.num2+Porc.micro.no.prod2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y+Sector:Servicios.num2, data=rep.dat)

summary(dist1)

reg.tab<-texreg(list(inst1,elec1,extra1,prog1,dist1),stars=c(.01,.05,.1))

reg.tab

##########################################################################################
### Figure 3: Organizational Traits and Programmatic Demand-Making, Predicted Values

# Creating a version of dataset without NAs on these variables for ggplot to function
newX<-rep.dat[!is.na(rep.dat$prog.index.6)&!is.na(rep.dat$inst.index.6)&!is.na(rep.dat$extra.inst.index)&!is.na(rep.dat$electoral.part.index)&!is.na(rep.dat$Sector),]

newX<-rep.dat[!is.na(rep.dat$prog.index.6)&!is.na(rep.dat$Sector),]

# Running the Programmatic Demands Model with this dataset
progX<-lm(prog.index.6~Recursos.num2+Servicios.num2+Porc.micro.no.prod2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y+Sector:Servicios.num2, data=newX)

summary(progX)

pdf(file="combined,prog.pdf",width=15,height=8)

a<-ggplot(data=newX,aes(y=predict(progX),x=Recursos.num2)) + geom_smooth(aes(linetype=Sector,color=Sector),method="glm")+ geom_rug(sides="b",position="jitter") + ylab(label="Programmatic Demands Index, Predicted Value") +xlab(label="Independent Resource Sources")+theme (axis.title=element_text(size=20), legend.position="none")

b<-ggplot(data=newX,aes(y=predict(progX),x=Servicios.num2))+ geom_smooth(aes(linetype=Sector, color=Sector) ,method="glm")+ geom_rug(sides="b",position="jitter") +xlab(label="Member Services") +theme(legend.position="bottom", axis.title=element_text(size=20), legend.text=element_text(size=20),legend.title=element_text(size=20), axis.title.y=element_blank())

c<-ggplot(data=newX,aes(y=predict(progX),x=Porc.micro.no.prod2)) + geom_smooth(aes(linetype=Sector,color=Sector),method="glm")+ geom_rug(sides="b",position="jitter") +xlab(label="Percent Micro Members")  +theme( axis.title=element_text(size=20), legend.position="none", axis.title.y=element_blank())

plot_grid(a,b,c,align="hv",axis="b",nrow=1)

dev.off()


##########################################################################################
### Figure 4: Modes of State Engagement and Programmatic Demand-Making, Predicted Values

# Creating version of dataset without NAs on key variables for ggplot to function
newX.med<-rep.dat[!is.na(rep.dat$prog.index.6)&!is.na(rep.dat$inst.index.6)&!is.na(rep.dat$extra.inst.index)&!is.na(rep.dat$electoral.part.index)&!is.na(rep.dat$Sector),]

medX<-lm(prog.index.6~inst.index.6+electoral.part.index+extra.inst.index+Recursos.num2+Servicios.num2+Porc.micro.no.prod2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y+Sector:Servicios.num2, data=newX.med)

summary(medX)

pdf(file="combined,mediation.pdf",width=15,height=8)

a<-ggplot(data=newX.med,aes(y=predict(medX),x=inst.index.6)) + geom_smooth(aes(linetype=Sector,color=Sector),method="glm")+ geom_rug(sides="b",position="jitter") + ylab(label="Programmatic Demands Index, Predicted Value") +xlab(label="Institutional Participation")+theme (axis.title=element_text(size=20), legend.position="none")

b<-ggplot(data=newX.med,aes(y=predict(medX),x=electoral.part.index))+ geom_smooth(aes(linetype=Sector, color=Sector) ,method="glm")+ geom_rug(sides="b",position="jitter") +xlab(label="Electoral Participation") +theme(legend.position="bottom", axis.title=element_text(size=20), legend.text=element_text(size=20),legend.title=element_text(size=20), axis.title.y=element_blank())

c<-ggplot(data=newX.med,aes(y=predict(medX),x=extra.inst.index)) + geom_smooth(aes(linetype=Sector,color=Sector),method="glm")+ geom_rug(sides="b",position="jitter") +xlab(label="Extra-Inst. Participation")  +theme( axis.title=element_text(size=20), legend.position="none", axis.title.y=element_blank())

plot_grid(a,b,c,align="hv",axis="b",nrow=1)

dev.off()


##########################################################################################
### Appendix B: Summary Statistics of Organizational Traits

# Resource Flows
tapply(rep.dat$Recursos.num,rep.dat$Sector,summary,na.rm=T)
tapply(rep.dat$Recursos.num,rep.dat$Sector,sd,na.rm=T)

# Member Services
tapply(rep.dat$Servicios.num,rep.dat$Sector,summary,na.rm=T)
tapply(rep.dat$Servicios.num,rep.dat$Sector,sd,na.rm=T)

# Class Composition
tapply(rep.dat$Porc.micro.no.prod,rep.dat$Sector,summary,na.rm=T)
tapply(rep.dat$Porc.micro.no.prod,rep.dat$Sector,sd,na.rm=T)

# Number of Members
tapply(rep.dat$Miembros.act,rep.dat$Sector,summary,na.rm=T)
tapply(rep.dat$Miembros.act,rep.dat$Sector,sd,na.rm=T)

# Member Fee %
tapply(rep.dat$Cuota.porc,rep.dat$Sector,summary,na.rm=T)
tapply(rep.dat$Cuota.porc,rep.dat$Sector,sd,na.rm=T)

# Number of Employees
tapply(rep.dat$Empleados,rep.dat$Sector,summary,na.rm=T)
tapply(rep.dat$Empleados,rep.dat$Sector,sd,na.rm=T)

# Org. Contact
tapply(rep.dat$Num.contacto.orgs,rep.dat$Sector,summary,na.rm=T)
tapply(rep.dat$Num.contacto.orgs,rep.dat$Sector,sd,na.rm=T)

# Meetings
tapply(rep.dat$Reunion.veces,rep.dat$Sector,summary,na.rm=T)
tapply(rep.dat$Reunion.veces,rep.dat$Sector,sd,na.rm=T)

# Meeting Attendance
tapply(rep.dat$Reunion.asist.porc,rep.dat$Sector,summary,na.rm=T)
tapply(rep.dat$Reunion.asist.porc,rep.dat$Sector,sd,na.rm=T)


###### Correlation Matrix of Organizational Traits

cor.dat<-rep.dat[,c(8,10,12,16)]

names(cor.dat)

cor.mat<-cor(cor.dat,use="na.or.complete")

xtable(cor.mat)


##########################################################################################
### Appendix C: Histograms, Participation and Demands Indices

pdf(file="index,hist.pdf",width=8,height=8)

par(mfrow=c(5,2), mar=c(2,2,2,2) + 0.4)

hist(rep.dat$inst.index.6[new2$Sector=="Agriculture"],main="Institutional Participation, Agriculture")
hist(rep.dat$inst.index.6[new2$Sector=="Business"],main="Institutional Participation, Business")

hist(rep.dat$electoral.part.index[new2$Sector=="Agriculture"],main="Electoral Participation, Agriculture")
hist(rep.dat$electoral.part.index[new2$Sector=="Business"], main="Electoral Participation, Business")

hist(rep.dat$extra.inst.index[new2$Sector=="Agriculture"], main="Extra-Institutional Participation, Agriculture")
hist(rep.dat$extra.inst.index[new2$Sector=="Business"], main="Extra-Institutional Participation, Business")

hist(rep.dat$prog.index.6[new2$Sector=="Agriculture"], main="Programmatic Demands, Agriculture")
hist(rep.dat$prog.index.6[new2$Sector=="Business"], main="Programmatic Demands, Business")

hist(rep.dat$subsidy.index.6[new2$Sector=="Agriculture"], main="Distributive Demands, Agriculture")
hist(rep.dat$subsidy.index.6[new2$Sector=="Business"], main="Distributive Demands, Business")

dev.off()


##########################################################################################
### Appendix D: Sensitivity Analysis

###### Sensitivity Analysis Using Only Complete Survey Responses

# Institutional Participation
inst1<-lm(inst.index.6~Recursos.num+Servicios.num+Porc.micro.no.prod+Sector+log(Miembros.act)+ruling.party3+vote.margin.y+Sector:Servicios.num, data=rep.dat)

summary(inst1)

# Electoral Participation
elec1<-lm(electoral.part.index~Recursos.num+Servicios.num+Porc.micro.no.prod+Sector+log(Miembros.act)+ruling.party3+vote.margin.y+Sector:Servicios.num, data=rep.dat)

summary(elec1)

# Extra-Institutional Participation
extra1<-lm(extra.inst.index~Recursos.num+Servicios.num+Porc.micro.no.prod+Sector+log(Miembros.act)+ruling.party3+vote.margin.y+Sector:Servicios.num, data=rep.dat)

summary(extra1)

# Programmatic Demands
prog1<-lm(prog.index.6~Recursos.num+Servicios.num+Porc.micro.no.prod+Sector+log(Miembros.act)+ruling.party3+vote.margin.y+Sector:Servicios.num, data=rep.dat)

summary(prog1)

# Distributive Demands
dist1<-lm(subsidy.index.6~Recursos.num+Servicios.num+Porc.micro.no.prod+Sector+log(Miembros.act)+ruling.party3+vote.margin.y+Sector:Servicios.num, data=rep.dat)

summary(dist1)

reg.tab<-texreg(list(inst1,elec1,extra1,prog1,dist1),stars=c(.01,.05,.1))

reg.tab


###### Sensitivity Analysis for Collinearity: Institutional Participation

# Resources
inst1<-lm(inst.index.6~Recursos.num2, data=rep.dat)
summary(inst1)

inst2<-lm(inst.index.6~Recursos.num2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y, data=rep.dat)
summary(inst2)

# Services
inst3<-lm(inst.index.6~Servicios.num2, data=rep.dat)
summary(inst3)

inst4<-lm(inst.index.6~Servicios.num2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y, data=rep.dat)
summary(inst4)

# % Micro Members
inst5<-lm(inst.index.6~Porc.micro.no.prod2, data=rep.dat)
summary(inst5)

inst6<-lm(inst.index.6~Porc.micro.no.prod2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y, data=rep.dat)
summary(inst6)

reg.tab<-texreg(list(inst1,inst2,inst3,inst4,inst5,inst6),stars=c(.01,.05,.1))

reg.tab

###### Sensitivity Analysis for Collinearity: Programmatic Demands

# Resources
prog1<-lm(prog.index.6~Recursos.num2, data=rep.dat)
summary(prog1)

prog2<-lm(prog.index.6~Recursos.num2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y, data=rep.dat)
summary(prog2)

# Services
prog3<-lm(prog.index.6~Servicios.num2, data=rep.dat)
summary(prog3)

prog4<-lm(prog.index.6~Servicios.num2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y, data=rep.dat)
summary(prog4)

# % Micro Members
prog5<-lm(prog.index.6~Porc.micro.no.prod2, data=rep.dat)
summary(prog5)

prog6<-lm(prog.index.6~Porc.micro.no.prod2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y, data=rep.dat)
summary(prog6)

reg.tab<-texreg(list(prog1,prog2,prog3,prog4,prog5,prog6),stars=c(.01,.05,.1))

reg.tab


###### Sensitivity Analysis for Social Desirability: Programmatic Demands

# Create new dichotomous versions of Programmmatic Demands, Resources, and Services

rep.dat$Servicios.bivar[rep.dat$Servicios.num2>2]<-1
rep.dat$Servicios.bivar[rep.dat$Servicios.num2<3]<-0

rep.dat$Recursos.bivar[rep.dat$Recursos.num2>2]<-1
rep.dat$Recursos.bivar[rep.dat$Recursos.num2<3]<-0

rep.dat$prog.bivar[rep.dat$prog.index.6>2]<-1
rep.dat$prog.bivar[rep.dat$prog.index.6<3]<-0

# Create a dataset removing units with extreme values on Programmatic Demands Index and Services

sd.robust.dat<-rep.dat[rep.dat$prog.index.6<6|rep.dat$Servicios.num2<5,]

# 1 
rec.bivar<-lm(prog.bivar~Recursos.bivar, data=rep.dat)
summary(rec.bivar)

# 2 
serv.bivar<-lm(prog.bivar~Servicios.bivar, data=rep.dat)
summary(serv.bivar)

# 3
prog1.bivar<-lm(prog.bivar~Recursos.bivar+Servicios.bivar+Porc.micro.no.prod2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y, data=rep.dat)
summary(prog1.bivar)

# 4
rec.robust<-lm(prog.index.6~Recursos.num2, data=sd.robust.dat)
summary(rec.robust)

# 5
serv.robust<-lm(prog.index.6~Servicios.num2, data=sd.robust.dat)
summary(serv.robust)

# 6
prog1.robust<-lm(prog.index.6~Recursos.num2+Servicios.num2+Porc.micro.no.prod2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y, data=sd.robust.dat)
summary(prog1.robust)


library(texreg)
reg.tab<-texreg(list(rec.bivar,serv.bivar,prog1.bivar,rec.robust,serv.robust,prog1.robust),stars=c(.01,.05,.1))

reg.tab


###### Sensitivity Analysis for Index Components

inst.comp1<-lm(Num.contacto.sec5~Recursos.num2+Servicios.num2+Porc.micro.no.prod2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y+Sector:Servicios.num2, data=rep.dat)

summary(inst.comp1)

inst.comp2<-lm(Num.contacto.pol~Recursos.num2+Servicios.num2+Porc.micro.no.prod2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y+Sector:Servicios.num2, data=rep.dat)

summary(inst.comp2)

prog.comp1<-glm(Contacto.obj.sec.programmatic1~Recursos.num2+Servicios.num2+Porc.micro.no.prod2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y+Sector:Servicios.num2, data=rep.dat,family=binomial)

summary(prog.comp1)

prog.comp2<-glm(Contacto.obj.pol.programmatic1~Recursos.num2+Servicios.num2+Porc.micro.no.prod2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y+Sector:Servicios.num2, data=rep.dat,family=binomial)

summary(prog.comp2)

prog.comp3<-glm(extra.inst.obj.programmatic1~Recursos.num2+Servicios.num2+Porc.micro.no.prod2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y+Sector:Servicios.num2, data=rep.dat,family=binomial)

summary(prog.comp3)

reg.tab.comp<-texreg(list(inst.comp1, inst.comp2,prog.comp1,prog.comp2,prog.comp3),stars=c(.01,.05,.1))

reg.tab.comp



##########################################################################################
### Appendix E: Multivariate Analysis for Intermediating Variables

med1<-lm(prog.index.6~Recursos.num2+Servicios.num2+Porc.micro.no.prod2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y+Sector:Servicios.num2, data=rep.dat)
summary(med1)

med2<-lm(prog.index.6~inst.index.6+Recursos.num2+Servicios.num2+Porc.micro.no.prod2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y+Sector:Servicios.num2, data=rep.dat)
summary(med2)

med3<-lm(prog.index.6~electoral.part.index+Recursos.num2+Servicios.num2+Porc.micro.no.prod2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y+Sector:Servicios.num2, data=rep.dat)
summary(med3)

med4<-lm(prog.index.6~extra.inst.index+Recursos.num2+Servicios.num2+Porc.micro.no.prod2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y+Sector:Servicios.num2, data=rep.dat)
summary(med4)

med5<-lm(prog.index.6~inst.index.6+electoral.part.index+extra.inst.index+Recursos.num2+Servicios.num2+Porc.micro.no.prod2+Sector+log(Miembros.act2)+ruling.party3+vote.margin.y+Sector:Servicios.num2, data=rep.dat)
summary(med5)

reg.tab.med<-texreg(list(med1,med2,med3,med4,med5),stars=c(.01,.05,.1))
reg.tab.med




